

## Description
my_package is a package used for calculating basic operation like summation, subtraction and multiplication.



## Installation
use package manager pip3 or pip to install my_package

terminal command:
--

pip3 install my_package

--

my_package doesn't have any dependencies.



## Usage
write the following command to use package-

\
from my_package import calculator
\

run the above code

the following is the result shown when we run the code;

*/
sahilsingh@sahils-MacBook-Air summer_school % python3 package.py
enter value to calculate: 
 1) summation 
 2) subtraction 
 3) multiplication 
Enter choice: 1
operand 1: 23
operand 2: 45
68.0                        # result
/*


The serial number of each operation is the choice for operation that we want to calculate, like in above example we choose (1) as choice, and, we get a sum of the two operands that we gave i.e.( 68.0 ). 